@@ -182,8 +182,8 @@ void SCIPimplicsGetVarImplicPoss(
    SCIP_IMPLICS*         implics,            /**< implications data structure */
    SCIP_Bool             varfixing,          /**< FALSE if y should be searched in implications for x == 0, TRUE for x == 1 */
    SCIP_VAR*             implvar,            /**< variable y to search for */
-   int*                  haslowerimplic,     /**< pointer to store the position of an implication y >= l */
-   int*                  hasupperimplic      /**< pointer to store the position of an implication y <= u */
+   int*                  lowerimplicpos,     /**< pointer to store the position of an implication y >= l */
+   int*                  upperimplicpos      /**< pointer to store the position of an implication y <= u */
    );
 
 /** returns whether an implication y <= b or y >= b is contained in implications for x == 0 or x == 1 */
